'\" te
.\" Copyright (c) 2001, the Institute of Electrical and Electronics Engineers, Inc. and The Open Group. All Rights Reserved.
.\" Portions Copyright (c) 2006, Sun Microsystems, Inc. All Rights Reserved.
.\" Sun Microsystems, Inc. gratefully acknowledges The Open Group for permission to reproduce portions of its copyrighted documentation. Original documentation from The Open Group can be obtained online at 
.\" http://www.opengroup.org/bookstore/.
.\" The Institute of Electrical and Electronics Engineers and The Open Group, have given us permission to reprint portions of their documentation. In the following statement, the phrase "this text" refers to portions of the system documentation. Portions of this text are reprinted and reproduced in electronic form in the Sun OS Reference Manual, from IEEE Std 1003.1, 2004 Edition, Standard for Information Technology -- Portable Operating System Interface (POSIX), The Open Group Base Specifications Issue 6, Copyright (C) 2001-2004 by the Institute of Electrical and Electronics Engineers, Inc and The Open Group. In the event of any discrepancy between these versions and the original IEEE and The Open Group Standard, the original IEEE and The Open Group Standard is the referee document. The original Standard can be obtained online at http://www.opengroup.org/unix/online.html.
.\"  This notice shall appear on any product containing this material.
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
.TH fegetround 3M "12 Jul 2006" "SunOS 5.11" "Mathematical Library Functions"
.SH NAME
fegetround, fesetround \- get and set current rounding direction
.SH SYNOPSIS
.LP
.nf
c99 [ \fIflag\fR... ] \fIfile\fR... \fB-lm\fR [ \fIlibrary\fR... ]
#include <fenv.h>

\fBint\fR \fBfegetround\fR(\fBvoid\fR);
.fi

.LP
.nf
\fBint\fR \fBfesetround\fR(\fBint\fR \fIround\fR);
.fi

.SH DESCRIPTION
.sp
.LP
The fegetround function gets the current rounding direction.
.sp
.LP
The fesetround function establishes the rounding direction represented by its
argument round. If the argument is not equal to the value of a rounding
direction macro, the rounding direction is not changed.
.SH RETURN VALUES
.sp
.LP
The fegetround function returns the value of the rounding direction macro
representing the current rounding direction, or a negative value if there is no
such rounding direction macro or the current rounding direction is not
determinable.
.sp
.LP
The fesetround function returns a 0 value if and only if the requested rounding
direction was established.
.SH ERRORS
.sp
.LP
No errors are defined.
.SH EXAMPLES
.sp
.LP
The following example saves, sets, and restores the rounding direction,
reporting an error and aborting if setting the rounding direction fails:
.LP
\fBExample 1 \fRSave, set, and restore the rounding direction.
.sp
.in +2
.nf
#include <fenv.h>
#include <assert.h>
void f(int round_dir)
{
      #pragma STDC FENV_ACCESS ON
      int save_round;
      int setround_ok;
      save_round = fegetround();
      setround_ok = fesetround(round_dir);
      assert(setround_ok == 0);
      /* ... */
      fesetround(save_round);
      /* ... */
}
.fi
.in -2

.SH ATTRIBUTES
.sp
.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp

.sp
.TS
tab() box;
cw(2.75i) |cw(2.75i) 
lw(2.75i) |lw(2.75i) 
.
ATTRIBUTE TYPEATTRIBUTE VALUE
_
Interface StabilityStandard
_
MT-LevelMT-Safe
.TE

.SH SEE ALSO
.sp
.LP
\fBfenv.h\fR(3HEAD), \fBattributes\fR(5), \fBstandards\fR(5)
